@@ -5,12 +5,12 @@ require "bundler/source/git/git_proxy"
 module Bundler
   class Env
     def write(io)
-      io.write report(:print_gemfile => true, :print_gemspecs => true)
+      io.write report
     end
 
     def report(options = {})
-      print_gemfile = options.delete(:print_gemfile)
-      print_gemspecs = options.delete(:print_gemspecs)
+      print_gemfile = options.delete(:print_gemfile) { true }
+      print_gemspecs = options.delete(:print_gemspecs) { true }
 
       out = String.new("## Environment\n\n```\n")
       out << "Bundler   #{Bundler::VERSION}\n"
